==> centercontrol-service-2.0.1-20200325.044217-10-sources.jar: com/bizvane/centercontrolservice/models/po/SysSmsConfigPo.java <==
package com.bizvane.centercontrolservice.models.po;

import java.io.Serializable;
import java.util.Date;

public class SysSmsConfigPo implements Serializable {

	/**
	 * 只读. 短信配置id. sys_sms_config_id
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "短信配置id", name = "sysSmsConfigId", required = false, example = "")
	private Long sysSmsConfigId;
	/**
	 * 只读. 企业id. sys_company_id
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false, example = "")
	private String sysCompanyId;
	/**
	 * 只读. 企业编号. company_code
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "企业编号", name = "companyCode", required = false, example = "")
	private String companyCode;
	/**
	 * 只读. 企业名称. company_name
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "企业名称", name = "companyName", required = false, example = "")
	private String companyName;
	/**
	 * 只读. 品牌id. sys_brand_id
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "sysBrandId", required = false, example = "")
	private Long sysBrandId;
	/**
	 * 只读. 品牌名称. brand_name
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "品牌名称", name = "brandName", required = false, example = "")
	private String brandName;
	/**
	 * 只读. 平台类型id 例如  1梦网，2三通. platform_type
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "平台类型id 例如  1梦网，2三通", name = "platformType", required = false, example = "")
	private Integer platformType;
	/**
	 * 只读. 通道类型：10=营销；20=验证码. channel_type
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "通道类型：10=营销；20=验证码", name = "channelType", required = false, example = "")
	private Integer channelType;
	/**
	 * 只读. 通道渠道：10=商帆；20=客户. channel
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "通道渠道：10=商帆；20=客户", name = "channel", required = false, example = "")
	private Integer channel;
	/**
	 * 只读. 通道名称：枚举. channel_name
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "通道名称：枚举", name = "channelName", required = false, example = "")
	private String channelName;
	/**
	 * 只读. 通道服务地址. channel_service
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "通道服务地址", name = "channelService", required = false, example = "")
	private String channelService;
	/**
	 * 只读. 批量短信的url. batch_channel_service
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "批量短信的url", name = "batchChannelService", required = false, example = "")
	private String batchChannelService;
	/**
	 * 只读. 通道账号. channel_account
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "通道账号", name = "channelAccount", required = false, example = "")
	private String channelAccount;
	/**
	 * 只读. 通道密码. channel_password
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "通道密码", name = "channelPassword", required = false, example = "")
	private String channelPassword;
	/**
	 * 只读. 单价. price
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "单价", name = "price", required = false, example = "")
	private Long price;
	/**
	 * 只读. 批量发送最大条数. batch_num
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "批量发送最大条数", name = "batchNum", required = false, example = "")
	private Integer batchNum;
	/**
	 * 只读. 签名. sign
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "签名", name = "sign", required = false, example = "")
	private String sign;
	/**
	 * 只读. 是否作为企业级短信通道，每个企业只能有一个，用于企业下账号修改密码的短信验证码发送等. company_channel
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "是否作为企业级短信通道，每个企业只能有一个，用于企业下账号修改密码的短信验证码发送等", name = "companyChannel", required = false, example = "")
	private Boolean companyChannel;
	/**
	 * 只读. 是否为国际短信通道. international
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "是否为国际短信通道", name = "international", required = false, example = "")
	private Boolean international;
	/**
	 * 只读. 备注. remark
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "备注", name = "remark", required = false, example = "")
	private String remark;
	/**
	 * 只读. 创建人id. create_user_id
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. 创建人. create_user_name
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. 创建日期. create_date
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建日期", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. 修改人id. modified_user_id
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. 修改人. modified_user_name
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. 修改时间. modified_date
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改时间", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 数据有效性：1=有效；0=无效. valid
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "数据有效性：1=有效；0=无效", name = "valid", required = false, example = "")
	private Boolean valid;

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public Long getSysSmsConfigId() {
		return sysSmsConfigId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setSysSmsConfigId(Long sysSmsConfigId) {
		this.sysSmsConfigId = sysSmsConfigId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public String getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setSysCompanyId(String sysCompanyId) {
		this.sysCompanyId = sysCompanyId == null ? null : sysCompanyId.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public String getCompanyCode() {
		return companyCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setCompanyCode(String companyCode) {
		this.companyCode = companyCode == null ? null : companyCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public String getCompanyName() {
		return companyName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setCompanyName(String companyName) {
		this.companyName = companyName == null ? null : companyName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public Long getSysBrandId() {
		return sysBrandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setSysBrandId(Long sysBrandId) {
		this.sysBrandId = sysBrandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public String getBrandName() {
		return brandName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setBrandName(String brandName) {
		this.brandName = brandName == null ? null : brandName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public Integer getPlatformType() {
		return platformType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setPlatformType(Integer platformType) {
		this.platformType = platformType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public Integer getChannelType() {
		return channelType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setChannelType(Integer channelType) {
		this.channelType = channelType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public Integer getChannel() {
		return channel;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setChannel(Integer channel) {
		this.channel = channel;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public String getChannelName() {
		return channelName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setChannelName(String channelName) {
		this.channelName = channelName == null ? null : channelName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public String getChannelService() {
		return channelService;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setChannelService(String channelService) {
		this.channelService = channelService == null ? null : channelService.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public String getBatchChannelService() {
		return batchChannelService;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setBatchChannelService(String batchChannelService) {
		this.batchChannelService = batchChannelService == null ? null : batchChannelService.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public String getChannelAccount() {
		return channelAccount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setChannelAccount(String channelAccount) {
		this.channelAccount = channelAccount == null ? null : channelAccount.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public String getChannelPassword() {
		return channelPassword;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setChannelPassword(String channelPassword) {
		this.channelPassword = channelPassword == null ? null : channelPassword.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public Long getPrice() {
		return price;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setPrice(Long price) {
		this.price = price;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public Integer getBatchNum() {
		return batchNum;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setBatchNum(Integer batchNum) {
		this.batchNum = batchNum;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public String getSign() {
		return sign;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setSign(String sign) {
		this.sign = sign == null ? null : sign.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public Boolean getCompanyChannel() {
		return companyChannel;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setCompanyChannel(Boolean companyChannel) {
		this.companyChannel = companyChannel;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public Boolean getInternational() {
		return international;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setInternational(Boolean international) {
		this.international = international;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public String getRemark() {
		return remark;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setRemark(String remark) {
		this.remark = remark == null ? null : remark.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}
}

==> centercontrol-service-2.0.1-20200723.020210-33-sources.jar: com/bizvane/centercontrolservice/models/po/SysSmsConfigPo.java <==
package com.bizvane.centercontrolservice.models.po;

import java.io.Serializable;
import java.util.Date;

public class SysSmsConfigPo implements Serializable {

	/**
	 * 只读. 短信配置id. sys_sms_config_id
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "短信配置id", name = "sysSmsConfigId", required = false, example = "")
	private Long sysSmsConfigId;
	/**
	 * 只读. 企业id. sys_company_id
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false, example = "")
	private String sysCompanyId;
	/**
	 * 只读. 企业编号. company_code
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "企业编号", name = "companyCode", required = false, example = "")
	private String companyCode;
	/**
	 * 只读. 企业名称. company_name
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "企业名称", name = "companyName", required = false, example = "")
	private String companyName;
	/**
	 * 只读. 品牌id. sys_brand_id
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "sysBrandId", required = false, example = "")
	private Long sysBrandId;

	// 品牌编号
	private String brandCode;
	/**
	 * 只读. 品牌名称. brand_name
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "品牌名称", name = "brandName", required = false, example = "")
	private String brandName;
	/**
	 * 只读. 平台类型id 例如  1梦网，2三通. platform_type
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "平台类型id 例如  1梦网，2三通", name = "platformType", required = false, example = "")
	private Integer platformType;
	/**
	 * 只读. 通道类型：10=营销；20=验证码. channel_type
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "通道类型：10=营销；20=验证码", name = "channelType", required = false, example = "")
	private Integer channelType;
	/**
	 * 只读. 通道渠道：10=商帆；20=客户. channel
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "通道渠道：10=商帆；20=客户", name = "channel", required = false, example = "")
	private Integer channel;
	// 商户号
	private String merchantId;
	/**
	 * 只读. 通道名称：枚举. channel_name
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "通道名称：枚举", name = "channelName", required = false, example = "")
	private String channelName;

	// 渠道中文名
	private String channelNewName;
	/**
	 * 只读. 通道服务地址. channel_service
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "通道服务地址", name = "channelService", required = false, example = "")
	private String channelService;
	/**
	 * 只读. 批量短信的url. batch_channel_service
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "批量短信的url", name = "batchChannelService", required = false, example = "")
	private String batchChannelService;
	/**
	 * 只读. 通道账号. channel_account
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "通道账号", name = "channelAccount", required = false, example = "")
	private String channelAccount;
	/**
	 * 只读. 通道密码. channel_password
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "通道密码", name = "channelPassword", required = false, example = "")
	private String channelPassword;
	/**
	 * 只读. 单价. price
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "单价", name = "price", required = false, example = "")
	private Long price;
	/**
	 * 只读. 批量发送最大条数. batch_num
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "批量发送最大条数", name = "batchNum", required = false, example = "")
	private Integer batchNum;
	/**
	 * 只读. 签名. sign
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "签名", name = "sign", required = false, example = "")
	private String sign;
	/**
	 * 只读. 是否作为企业级短信通道，每个企业只能有一个，用于企业下账号修改密码的短信验证码发送等. company_channel
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "是否作为企业级短信通道，每个企业只能有一个，用于企业下账号修改密码的短信验证码发送等", name = "companyChannel", required = false, example = "")
	private Boolean companyChannel;
	/**
	 * 只读. 是否为国际短信通道. international
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "是否为国际短信通道", name = "international", required = false, example = "")
	private Boolean international;
	/**
	 * 只读. 备注. remark
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "备注", name = "remark", required = false, example = "")
	private String remark;
	/**
	 * 只读. 创建人id. create_user_id
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. 创建人. create_user_name
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. 创建日期. create_date
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建日期", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. 修改人id. modified_user_id
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. 修改人. modified_user_name
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. 修改时间. modified_date
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改时间", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 数据有效性：1=有效；0=无效. valid
	 * @mbg.generated  2018-08-21 11:13:52
	 */
	@io.swagger.annotations.ApiModelProperty(value = "数据有效性：1=有效；0=无效", name = "valid", required = false, example = "")
	private Boolean valid;

	// 创蓝必须，阿里否
	private String appId;

	// 创蓝必须，阿里否 新增模板账号
	private String deepPassword;
	// 创蓝必须，阿里否 新增模板密码
	private String deepUsername;

	// 创蓝必须，阿里否
	private Integer subId;
	// 退订方式
	private String unsubscribeText;

	public Long getSysSmsConfigId() {
		return sysSmsConfigId;
	}

	public void setSysSmsConfigId(Long sysSmsConfigId) {
		this.sysSmsConfigId = sysSmsConfigId;
	}

	public String getSysCompanyId() {
		return sysCompanyId;
	}

	public void setSysCompanyId(String sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	public String getCompanyCode() {
		return companyCode;
	}

	public void setCompanyCode(String companyCode) {
		this.companyCode = companyCode;
	}

	public String getCompanyName() {
		return companyName;
	}

	public void setCompanyName(String companyName) {
		this.companyName = companyName;
	}

	public Long getSysBrandId() {
		return sysBrandId;
	}

	public void setSysBrandId(Long sysBrandId) {
		this.sysBrandId = sysBrandId;
	}

	public String getBrandCode() {
		return brandCode;
	}

	public void setBrandCode(String brandCode) {
		this.brandCode = brandCode;
	}

	public String getBrandName() {
		return brandName;
	}

	public void setBrandName(String brandName) {
		this.brandName = brandName;
	}

	public Integer getPlatformType() {
		return platformType;
	}

	public void setPlatformType(Integer platformType) {
		this.platformType = platformType;
	}

	public Integer getChannelType() {
		return channelType;
	}

	public void setChannelType(Integer channelType) {
		this.channelType = channelType;
	}

	public Integer getChannel() {
		return channel;
	}

	public void setChannel(Integer channel) {
		this.channel = channel;
	}

	public String getMerchantId() {
		return merchantId;
	}

	public void setMerchantId(String merchantId) {
		this.merchantId = merchantId;
	}

	public String getChannelName() {
		return channelName;
	}

	public void setChannelName(String channelName) {
		this.channelName = channelName;
	}

	public String getChannelNewName() {
		return channelNewName;
	}

	public void setChannelNewName(String channelNewName) {
		this.channelNewName = channelNewName;
	}

	public String getChannelService() {
		return channelService;
	}

	public void setChannelService(String channelService) {
		this.channelService = channelService;
	}

	public String getBatchChannelService() {
		return batchChannelService;
	}

	public void setBatchChannelService(String batchChannelService) {
		this.batchChannelService = batchChannelService;
	}

	public String getChannelAccount() {
		return channelAccount;
	}

	public void setChannelAccount(String channelAccount) {
		this.channelAccount = channelAccount;
	}

	public String getChannelPassword() {
		return channelPassword;
	}

	public void setChannelPassword(String channelPassword) {
		this.channelPassword = channelPassword;
	}

	public Long getPrice() {
		return price;
	}

	public void setPrice(Long price) {
		this.price = price;
	}

	public Integer getBatchNum() {
		return batchNum;
	}

	public void setBatchNum(Integer batchNum) {
		this.batchNum = batchNum;
	}

	public String getSign() {
		return sign;
	}

	public void setSign(String sign) {
		this.sign = sign;
	}

	public Boolean getCompanyChannel() {
		return companyChannel;
	}

	public void setCompanyChannel(Boolean companyChannel) {
		this.companyChannel = companyChannel;
	}

	public Boolean getInternational() {
		return international;
	}

	public void setInternational(Boolean international) {
		this.international = international;
	}

	public String getRemark() {
		return remark;
	}

	public void setRemark(String remark) {
		this.remark = remark;
	}

	public Long getCreateUserId() {
		return createUserId;
	}

	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	public String getCreateUserName() {
		return createUserName;
	}

	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName;
	}

	public Date getCreateDate() {
		return createDate;
	}

	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	public String getModifiedUserName() {
		return modifiedUserName;
	}

	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName;
	}

	public Date getModifiedDate() {
		return modifiedDate;
	}

	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	public Boolean getValid() {
		return valid;
	}

	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	public String getAppId() {
		return appId;
	}

	public void setAppId(String appId) {
		this.appId = appId;
	}

	public String getDeepPassword() {
		return deepPassword;
	}

	public void setDeepPassword(String deepPassword) {
		this.deepPassword = deepPassword;
	}

	public String getDeepUsername() {
		return deepUsername;
	}

	public void setDeepUsername(String deepUsername) {
		this.deepUsername = deepUsername;
	}

	public Integer getSubId() {
		return subId;
	}

	public void setSubId(Integer subId) {
		this.subId = subId;
	}

	public String getUnsubscribeText() {
		return unsubscribeText;
	}

	public void setUnsubscribeText(String unsubscribeText) {
		this.unsubscribeText = unsubscribeText;
	}
}
